@@ -79,7 +79,7 @@ def getIntermediateCoords(ra, dec, scale, img_xmax, img_ymax, shape, filter, cat
         axes_query.set_title('Sky coordinates')
         axes_query.set_xlabel('Right ascension (degrees)')
         axes_query.set_ylabel('Declination (degrees)')
-        axes_query.scatter(catalog_points[:,0],catalog_points[:,1],marker=".",color='red')
+        axes_query.scatter(catalog_points[:,0]*180/pi,catalog_points[:,1]*180/pi,marker=".",color='red')
         axes_query.scatter([a0deg],[d0deg],marker="x",color='black')
 
         axes_proj = fig.add_subplot(122)
